@@ -126,7 +126,7 @@ public:
     void connectUrlNavigator(DolphinUrlNavigator *urlNavigator);
 
     /**
-     * Disconnects the navigator that is currently controling the view.
+     * Disconnects the navigator that is currently controlling the view.
      * This method completely reverses connectUrlNavigator().
      */
     void disconnectUrlNavigator();
@@ -229,6 +229,16 @@ Q_SIGNALS:
      */
     void captionChanged();
 
+    /**
+     * Is emitted if a new tab should be opened in the background for the URL \a url.
+     */
+    void tabRequested(const QUrl &url);
+
+    /**
+     * Is emitted if a new tab should be opened for the URL \a url and set as active.
+     */
+    void activeTabRequested(const QUrl &url);
+
 private Q_SLOTS:
     /**
      * Updates the number of items (= number of files + number of
@@ -281,7 +291,7 @@ private Q_SLOTS:
      * directory is opened in the view. If the item is a file, the file
      * gets started by the corresponding application.
      */
-    void slotItemActivated(const KFileItem& item);
+    void slotItemActivated(const KFileItem &item);
 
     /**
      * Handles activation of multiple files. The files get started by
@@ -361,6 +371,11 @@ private Q_SLOTS:
      */
     void slotPlacesModelChanged();
 
+    void slotHiddenFilesShownChanged(bool showHiddenFiles);
+    void slotSortHiddenLastChanged(bool hiddenLast);
+
+    void slotOpenUrlFinished(KJob* job);
+
 private:
     /**
      * @return True if the URL protocol is a search URL (e. g. baloosearch:// or filenamesearch://).
