@@ -15,12 +15,12 @@ TrashSettingsPage::TrashSettingsPage(QWidget* parent) :
 {
     QFormLayout* topLayout = new QFormLayout(this);
 
-    m_proxy = new KCModuleProxy(QStringLiteral("kcmtrash"));
+    m_proxy = new KCModuleProxy(KPluginMetaData(QStringLiteral("kcm_trash")));
     topLayout->addRow(m_proxy);
 
     loadSettings();
 
-    connect(m_proxy, QOverload<bool>::of(&KCModuleProxy::changed), this, &TrashSettingsPage::changed);
+    connect(m_proxy, &KCModuleProxy::changed, this, &TrashSettingsPage::changed);
 }
 
 TrashSettingsPage::~TrashSettingsPage()
